# Generated by Django 3.1.9 on 2021-05-06 15:44

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("authentication", "0017_remove_fleetup_permission"),
        ("eveonline", "0014_auto_20210105_1413"),
        ("freight", "0016_default_pricing"),
    ]

    operations = [
        migrations.AlterField(
            model_name="contract",
            name="acceptor",
            field=models.ForeignKey(
                blank=True,
                default=None,
                help_text="character of acceptor or None if accepted by corp",
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="contracts_acceptor",
                to="eveonline.evecharacter",
            ),
        ),
        migrations.AlterField(
            model_name="contract",
            name="acceptor_corporation",
            field=models.ForeignKey(
                blank=True,
                default=None,
                help_text="corporation of acceptor",
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="contracts_acceptor_corporation",
                to="eveonline.evecorporationinfo",
            ),
        ),
        migrations.AlterField(
            model_name="contract",
            name="date_notified",
            field=models.DateTimeField(
                blank=True,
                db_index=True,
                default=None,
                help_text="datetime of latest notification, None = none has been sent",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="contract",
            name="end_location",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="contracts_end_location",
                to="freight.location",
            ),
        ),
        migrations.AlterField(
            model_name="contract",
            name="handler",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="contracts",
                to="freight.contracthandler",
            ),
        ),
        migrations.AlterField(
            model_name="contract",
            name="issuer",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="contracts_issuer",
                to="eveonline.evecharacter",
            ),
        ),
        migrations.AlterField(
            model_name="contract",
            name="issuer_corporation",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="contracts_issuer_corporation",
                to="eveonline.evecorporationinfo",
            ),
        ),
        migrations.AlterField(
            model_name="contract",
            name="pricing",
            field=models.ForeignKey(
                blank=True,
                default=None,
                null=True,
                on_delete=django.db.models.deletion.SET_DEFAULT,
                related_name="contracts",
                to="freight.pricing",
            ),
        ),
        migrations.AlterField(
            model_name="contract",
            name="start_location",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="contracts_start_location",
                to="freight.location",
            ),
        ),
        migrations.AlterField(
            model_name="contract",
            name="status",
            field=models.CharField(
                choices=[
                    ("outstanding", "outstanding"),
                    ("in_progress", "in progress"),
                    ("finished_issuer", "finished issuer"),
                    ("finished_contractor", "finished contractor"),
                    ("finished", "finished"),
                    ("canceled", "canceled"),
                    ("rejected", "rejected"),
                    ("failed", "failed"),
                    ("deleted", "deleted"),
                    ("reversed", "reversed"),
                ],
                db_index=True,
                max_length=32,
            ),
        ),
        migrations.AlterField(
            model_name="contractcustomernotification",
            name="contract",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="customer_notifications",
                to="freight.contract",
            ),
        ),
        migrations.AlterField(
            model_name="contractcustomernotification",
            name="status",
            field=models.CharField(
                choices=[
                    ("outstanding", "outstanding"),
                    ("in_progress", "in progress"),
                    ("finished_issuer", "finished issuer"),
                    ("finished_contractor", "finished contractor"),
                    ("finished", "finished"),
                    ("canceled", "canceled"),
                    ("rejected", "rejected"),
                    ("failed", "failed"),
                    ("deleted", "deleted"),
                    ("reversed", "reversed"),
                ],
                db_index=True,
                max_length=32,
            ),
        ),
        migrations.AlterField(
            model_name="contracthandler",
            name="character",
            field=models.ForeignKey(
                default=None,
                help_text="character used for syncing contracts",
                null=True,
                on_delete=django.db.models.deletion.SET_DEFAULT,
                related_name="+",
                to="authentication.characterownership",
            ),
        ),
        migrations.AlterField(
            model_name="location",
            name="name",
            field=models.CharField(
                db_index=True,
                help_text="In-game name of this station or structure",
                max_length=100,
            ),
        ),
        migrations.AlterField(
            model_name="pricing",
            name="end_location",
            field=models.ForeignKey(
                help_text="Destination station or structure for courier route",
                on_delete=django.db.models.deletion.CASCADE,
                related_name="+",
                to="freight.location",
            ),
        ),
        migrations.AlterField(
            model_name="pricing",
            name="start_location",
            field=models.ForeignKey(
                help_text="Starting station or structure for courier route",
                on_delete=django.db.models.deletion.CASCADE,
                related_name="+",
                to="freight.location",
            ),
        ),
    ]
