 <div class="table-responsive">
    <table class="table table-striped table-width-fix tab-contract" id="{{ tab_name }}">
        <thead>
            <tr>
                <th>Status</th>
                <th>Start</th>
                <th>Destination</th>
                <th>Reward<br>&nbsp;ISK</th>
                <th>Collateral<br>&nbsp;ISK</th>
                <th>Volume<br>&nbsp;m3</th>
                <th>Contract<br>Check</th>
                <th>Issued<br>On</th>
                <th>Expires<br>On</th>
                <th>Issued<br>By</th>
                <th>Accepted<br>On</th>
                <th>Accepted<br>By</th>
            </tr>
        </thead>
        <tbody>
        </tbody>
    </table>
</div>
