{% extends 'allianceauth/base.html' %}
{% load i18n %}
{% block page_title %}{{ app_title }}{% endblock %}

{% block content %}
    <br />
    {% include 'freight/partials/menu.html' %}
    <h2>{{ page_title }}</h2>
    {% block details %}{% endblock %}
{% endblock %}
