# Generated by Django 2.2.9 on 2020-01-30 23:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("freight", "0014_auto_20191214_1712"),
    ]

    operations = [
        migrations.RenameField(
            model_name="pricing",
            old_name="active",
            new_name="is_active",
        ),
        migrations.AddField(
            model_name="pricing",
            name="is_bidirectional",
            field=models.BooleanField(
                default=True,
                help_text="Whether this pricing is valid for contracts in either direction or only the one specified",
            ),
        ),
    ]
