# Generated by Django 2.2.8 on 2019-12-14 15:22

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("eveonline", "0010_alliance_ticker"),
        ("freight", "0012_auto_20191210_1406"),
    ]

    operations = [
        migrations.AddField(
            model_name="contract",
            name="acceptor_corporation",
            field=models.ForeignKey(
                blank=True,
                default=None,
                help_text="corporation of acceptor",
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="contract_acceptor_corporation",
                to="eveonline.EveCorporationInfo",
            ),
        ),
        migrations.AlterField(
            model_name="contract",
            name="acceptor",
            field=models.ForeignKey(
                blank=True,
                default=None,
                help_text="character of acceptor or None if accepted by corp",
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="contract_acceptor",
                to="eveonline.EveCharacter",
            ),
        ),
        migrations.AlterField(
            model_name="contract",
            name="issuer_corporation",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="contract_issuer_corporation",
                to="eveonline.EveCorporationInfo",
            ),
        ),
        migrations.AlterField(
            model_name="eveorganization",
            name="category",
            field=models.CharField(
                choices=[
                    ("alliance", "Alliance"),
                    ("corporation", "Corporation"),
                    ("character", "Character"),
                ],
                max_length=32,
            ),
        ),
    ]
